import pymc3 as pm
import numpy as np
import matplotlib.pyplot as plt

Data = [# ID  SA  SB
        ['A', 15, 15],
        ['A', 16, 16],
        ['A', 12, 19],
        ['A', 19, 12],
        ['B', 25, 25],
        ['B', 26, 26],
        ['B', 22, 29],
        ['B', 29, 22],
        ['C', 35, 35],
        ['C', 36, 36],
        ['C', 32, 39],
        ['C', 39, 32]
        ]

N = len(Data)
Y = []
X = []
for v in Data:
    Y.append(v[2])
    X.append(v[1])

with pm.Model() as SReg2:
	b0 = pm.Uniform('b0', lower = -1000, upper = 1000)
	b1 = pm.Uniform('b1', lower = -1000, upper = 1000)
	Y_est = b0 + b1 * X
	sgm = pm.Uniform('sgm', lower = 0, upper = 1000)
	Y_obs = pm.Normal('Y_obs', mu = Y_est, sd = sgm, observed = Y)
	trace = pm.sample()
	pm.traceplot(trace)
	plt.show()

	summary_trace = pm.summary(trace)
	print('\n',summary_trace)

	smpl_b1 = trace['b1']
	n_smpls = len(smpl_b1)
	b1_pos = 0
	for v in smpl_b1:
		if v > 0.0:
		    b1_pos += 1
	plt.hist(smpl_b1)
	plt.xlabel('b1')
	plt.title('Prop(b1 > 0) = {0:.3f}'.format(b1_pos/n_smpls))
	plt.show()

	smpl_b0 = trace['b0']
	Yregs = []
	for j in range(N):
		Yregs.append([])
	for sb0, sb1 in zip(smpl_b0, smpl_b1):
		for j in range(N):
			Yregs[j].append(sb0 + sb1 * X[j])	

	meanYreg = [0] * N
	for i in range(N):
		meanYreg[i] = np.median(Yregs[i])

	plt.plot(meanYreg, Y, 'bo')
	minX = np.amin(meanYreg)
	maxX = np.amax(meanYreg)
	plt.plot([minX, maxX], [minX, maxX], 'b--', label = 'y = x')
	plt.legend(loc = 2)
	plt.xlabel('Yreg')
	plt.ylabel('Y')
	plt.show()

